pyxmpp.exceptions.BadRequestProtocolError

Package pyxmpp :: Module exceptions :: Class BadRequestProtocolError |
[hide private]

# Class BadRequestProtocolError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
                                   Error --+
                                           |
                               ProtocolError --+
                                               |
                                              BadRequestProtocolError

Raised when invalid stanza is processed and 'bad-request' error should be reported.

Instance Methods | [hide private]
__init__(self, message) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `ProtocolError`: `__repr__`, `__unicode__`, `log_ignored`, `log_reported` Inherited from `exceptions.StandardError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `ProtocolError`: `logger_ignored`, `logger_reported`

Instance Variables | [hide private]
Inherited from `ProtocolError`: `message`, `xmpp_name`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, message) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)